==> manydhcp2.5.2.tar.bz2: manydhcp/users/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['upr-title-del'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_GET['addr_id'])) {puterror($result2['skin'],$TEXT['error-upr5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['addr_id'])>5) {puterror($result2['skin'],$TEXT['error-upr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['addr_id'] = rep ($_GET['addr_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT 
     tbl_upr.usr,
     tbl_upr.srv_id,
     tbl_srv.srv_id,
     tbl_srv.name AS srv_name,
     tbl_srv.descr AS srv_descr
     FROM tbl_upr
     JOIN tbl_srv ON tbl_upr.srv_id=tbl_srv.srv_id
     WHERE tbl_upr.addr_id='".$_GET['addr_id']."' ";
  $result3 = mysql_query($query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysql_fetch_array($result3);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-upr2'];
  $what = $result4['usr']." (".$TEXT['log-srv4'].$result4['srv_name']. " (".$result4['srv_descr'].")) ".$TEXT['log-id'].$_GET['addr_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_upr` WHERE `addr_id`='".$_GET['addr_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/users/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['upr-title-del'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
  if(empty($_GET['addr_id'])) {puterror($result2['skin'],$TEXT['error-upr5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['addr_id'])>5) {puterror($result2['skin'],$TEXT['error-upr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['addr_id'] = rep ($_GET['addr_id']);

  //*************************************
  //Информация для лога
  $query3 = "SELECT 
     tbl_upr.usr,
     tbl_upr.srv_id,
     tbl_srv.srv_id,
     tbl_srv.name AS srv_name,
     tbl_srv.descr AS srv_descr
     FROM tbl_upr
     JOIN tbl_srv ON tbl_upr.srv_id=tbl_srv.srv_id
     WHERE tbl_upr.addr_id='".$_GET['addr_id']."' ";
  $result3 = mysqli_query($dbcnx,$query3);
  if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
      $result4 = mysqli_fetch_array($result3,MYSQLI_ASSOC);

  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-upr2'];
  $what = $result4['usr']." (".$TEXT['log-srv4'].$result4['srv_name']. " (".$result4['srv_descr'].")) ".$TEXT['log-id'].$_GET['addr_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_upr` WHERE `addr_id`='".$_GET['addr_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
